@@ -1,4 +1,5 @@
 """Test kernel for signalling subprocesses"""
+
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 import os
@@ -62,7 +63,7 @@ class SignalTestKernel(Kernel):
 
 
 class SignalTestApp(IPKernelApp):
-    kernel_class = SignalTestKernel
+    kernel_class = SignalTestKernel  # type:ignore[assignment]
 
     def init_io(self):
         # Overridden to disable stdout/stderr capture
