@@ -1,14 +1,17 @@
 """Tests for the notebook kernel and session manager."""
+
 import asyncio
 import concurrent.futures
 import os
 import sys
+import sysconfig
 import uuid
 from asyncio import ensure_future
 from subprocess import PIPE
 from unittest import TestCase
 
 import pytest
+import zmq
 from jupyter_core import paths
 from tornado.testing import AsyncTestCase, gen_test
 from traitlets.config.loader import Config
@@ -26,7 +29,9 @@ from .utils import (
     skip_win32,
 )
 
-TIMEOUT = 30
+TIMEOUT = 90
+
+is_freethreaded = bool(sysconfig.get_config_var("Py_GIL_DISABLED"))
 
 
 async def now(awaitable):
@@ -38,7 +43,12 @@ async def now(awaitable):
 
 
 class TestKernelManager(TestCase):
+    def tearDown(self):
+        zmq.Context.instance().destroy(linger=0)
+        return super().tearDown()
+
     # static so picklable for multiprocessing on Windows
+
     @staticmethod
     def _get_tcp_km():
         c = Config()
@@ -83,6 +93,7 @@ class TestKernelManager(TestCase):
         km.shutdown_kernel(kid, now=True)
         assert kid not in km, f"{kid} not in {km}"
         kc.stop_channels()
+        km.context.destroy(linger=0)
 
     def _run_cinfo(self, km, transport, ip):
         kid = km.start_kernel(stdout=PIPE, stderr=PIPE)
@@ -101,6 +112,7 @@ class TestKernelManager(TestCase):
         stream = km.connect_hb(kid)
         stream.close()
         km.shutdown_kernel(kid, now=True)
+        km.context.destroy(linger=0)
 
     # static so picklable for multiprocessing on Windows
     @classmethod
@@ -120,6 +132,7 @@ class TestKernelManager(TestCase):
         self.assertNotIn(kid, km)
         # shutdown again is okay, because we have no kernels
         km.shutdown_all()
+        km.context.destroy(linger=0)
 
     def test_tcp_cinfo(self):
         km = self._get_tcp_km()
@@ -150,11 +163,12 @@ class TestKernelManager(TestCase):
 
     def tcp_lifecycle_with_loop(self):
         # Ensure each thread has an event loop
-        loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(loop)
-        self.test_tcp_lifecycle()
-        loop.close()
+        async def _task():
+            return self.test_tcp_lifecycle()
 
+        asyncio.run(_task())
+
+    @pytest.mark.skipif(is_freethreaded, reason="Fail on free-threaded python")
     def test_start_parallel_thread_kernels(self):
         self.test_tcp_lifecycle()
 
@@ -164,13 +178,9 @@ class TestKernelManager(TestCase):
             future1.result()
             future2.result()
 
-    @pytest.mark.skipif(
-        (sys.platform == "darwin") and (sys.version_info >= (3, 6)) and (sys.version_info < (3, 8)),
-        reason='"Bad file descriptor" error',
-    )
     @pytest.mark.skipif(
         sys.platform == "linux",
-        reason='Kernel refuses to start in process pool',
+        reason="Kernel refuses to start in process pool",
     )
     def test_start_parallel_process_kernels(self):
         self.test_tcp_lifecycle()
@@ -249,7 +259,7 @@ class TestKernelManager(TestCase):
         def record_activity(msg_list):
             nonlocal called
             """Record an IOPub message arriving from a kernel"""
-            idents, fed_msg_list = session.feed_identities(msg_list)
+            _idents, fed_msg_list = session.feed_identities(msg_list)
             msg = session.deserialize(fed_msg_list, content=False)
 
             msg_type = msg["header"]["msg_type"]
@@ -264,12 +274,16 @@ class TestKernelManager(TestCase):
             time.sleep(0.1)
             if called:
                 break
-
+        stream.close()
         client.stop_channels()
         km.shutdown_kernel(now=True)
 
 
 class TestAsyncKernelManager(AsyncTestCase):
+    def tearDown(self):
+        zmq.Context.instance().destroy(linger=0)
+        return super().tearDown()
+
     # static so picklable for multiprocessing on Windows
     @staticmethod
     def _get_tcp_km():
@@ -321,6 +335,8 @@ class TestAsyncKernelManager(AsyncTestCase):
         assert isinstance(k, AsyncKernelManager)
         await km.shutdown_kernel(kid, now=True)
         assert kid not in km, f"{kid} not in {km}"
+        await km.shutdown_all()
+        km.context.destroy(linger=100)
 
     async def _run_cinfo(self, km, transport, ip):
         kid = await km.start_kernel(stdout=PIPE, stderr=PIPE)
@@ -340,6 +356,7 @@ class TestAsyncKernelManager(AsyncTestCase):
         stream.close()
         await km.shutdown_kernel(kid, now=True)
         self.assertNotIn(kid, km)
+        km.context.destroy(linger=0)
 
     @gen_test
     async def test_tcp_lifecycle(self):
@@ -391,6 +408,7 @@ class TestAsyncKernelManager(AsyncTestCase):
         self.assertNotIn(kid, km)
         # shutdown again is okay, because we have no kernels
         await km.shutdown_all()
+        km.context.destroy(linger=0)
 
     @gen_test
     async def test_use_pending_kernels(self):
@@ -411,6 +429,7 @@ class TestAsyncKernelManager(AsyncTestCase):
         k = km.get_kernel(kid)
         assert isinstance(k, AsyncKernelManager)
         await ensure_future(km.shutdown_kernel(kid, now=True))
+        km.context.destroy(linger=0)
         # Wait for the kernel to shutdown
         await kernel.ready
         assert kid not in km, f"{kid} not in {km}"
@@ -428,6 +447,7 @@ class TestAsyncKernelManager(AsyncTestCase):
         # Wait for the kernel to shutdown
         await kernel.ready
         assert kid not in km, f"{kid} not in {km}"
+        km.context.destroy(linger=0)
 
     @gen_test
     async def test_use_pending_kernels_early_shutdown(self):
@@ -440,6 +460,7 @@ class TestAsyncKernelManager(AsyncTestCase):
         # Wait for the kernel to shutdown
         await kernel.ready
         assert kid not in km, f"{kid} not in {km}"
+        km.context.destroy(linger=0)
 
     @gen_test
     async def test_use_pending_kernels_early_interrupt(self):
@@ -455,23 +476,27 @@ class TestAsyncKernelManager(AsyncTestCase):
         # Wait for the kernel to shutdown
         await kernel.ready
         assert kid not in km, f"{kid} not in {km}"
+        km.context.destroy(linger=0)
 
     @gen_test
     async def test_tcp_cinfo(self):
         km = self._get_tcp_km()
         await self._run_cinfo(km, "tcp", localhost())
+        km.context.destroy(linger=0)
 
     @skip_win32
     @gen_test
     async def test_ipc_lifecycle(self):
         km = self._get_ipc_km()
         await self._run_lifecycle(km)
+        km.context.destroy(linger=0)
 
     @skip_win32
     @gen_test
     async def test_ipc_cinfo(self):
         km = self._get_ipc_km()
         await self._run_cinfo(km, "ipc", "test")
+        km.context.destroy(linger=0)
 
     @gen_test
     async def test_start_sequence_tcp_kernels(self):
@@ -579,6 +604,7 @@ class TestAsyncKernelManager(AsyncTestCase):
         mkm.get_kernel(kid).reset_counts()
         mkm.reset_counts()
         await mkm.shutdown_all(now=True)
+        mkm.context.destroy(linger=0)
         assert mkm.call_count("remove_kernel") == 1
         assert mkm.call_count("_async_request_shutdown") == 0
         assert mkm.call_count("_async_finish_shutdown") == 0
@@ -596,6 +622,7 @@ class TestAsyncKernelManager(AsyncTestCase):
         )
         with pytest.raises(FileNotFoundError):
             await ensure_future(km.start_kernel(kernel_name="bad", stdout=PIPE, stderr=PIPE))
+        km.context.destroy(linger=0)
 
     @gen_test
     async def test_bad_kernelspec_pending(self):
@@ -613,8 +640,9 @@ class TestAsyncKernelManager(AsyncTestCase):
         assert kernel_id in km.list_kernel_ids()
         await ensure_future(km.shutdown_kernel(kernel_id))
         assert kernel_id not in km.list_kernel_ids()
+        km.context.destroy(linger=0)
 
-    @gen_test
+    @gen_test(timeout=TIMEOUT)
     async def test_stream_on_recv(self):
         mkm = self._get_tcp_km()
         kid = await mkm.start_kernel(stdout=PIPE, stderr=PIPE)
@@ -628,7 +656,7 @@ class TestAsyncKernelManager(AsyncTestCase):
         def record_activity(msg_list):
             nonlocal called
             """Record an IOPub message arriving from a kernel"""
-            idents, fed_msg_list = session.feed_identities(msg_list)
+            _idents, fed_msg_list = session.feed_identities(msg_list)
             msg = session.deserialize(fed_msg_list, content=False)
 
             msg_type = msg["header"]["msg_type"]
@@ -643,4 +671,6 @@ class TestAsyncKernelManager(AsyncTestCase):
             await asyncio.sleep(0.1)
 
         client.stop_channels()
+        stream.close()
         await km.shutdown_kernel(now=True)
+        km.context.destroy(linger=0)
